@@ -221,7 +221,7 @@ def qePwContinueSubmit(results, pk, codename='', add_parameters={}, del_paramete
         computer = node.computer.label
         restart_builder = node.get_builder_restart() # get the restart_builder
     else:
-        copmuter = codename.split('@')[1]
+        computer = codename.split('@')[1]
         code = Code.get_from_string(codename)
         restart_builder = code.get_builder()
 
